#
# GAMS - General Algebraic Modeling System Python API
#
# Copyright (c) 2023 GAMS Development Corp. <support@gams.com>
# Copyright (c) 2023 GAMS Software GmbH <support@gams.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
from __future__ import annotations

from gamspy.math.log_power import (
    cv_power,
    exp,
    log,
    log2,
    log10,
    log_beta,
    log_gamma,
    logit,
    power,
    rpower,
    sign_power,
    sllog10,
    sqlog10,
    sqr,
    vc_power,
)
from gamspy.math.misc import (
    Max,
    Min,
    Round,
    abs,
    beta,
    bool_and,
    bool_eqv,
    bool_imp,
    bool_not,
    bool_or,
    bool_xor,
    ceil,
    dist,
    div,
    div0,
    entropy,
    errorf,
    factorial,
    floor,
    fractional,
    gamma,
    ifthen,
    lse_max,
    lse_max_sc,
    lse_min,
    lse_min_sc,
    mod,
    ncp_cm,
    ncp_f,
    ncpVUpow,
    ncpVUsin,
    poly,
    rand_binomial,
    rand_linear,
    rand_triangle,
    regularized_beta,
    regularized_gamma,
    rel_eq,
    rel_ge,
    rel_gt,
    rel_le,
    rel_lt,
    rel_ne,
    same_as,
    sigmoid,
    sign,
    slexp,
    slrec,
    sqexp,
    sqrec,
    sqrt,
    truncate,
)
from gamspy.math.probability import (
    binomial,
    centropy,
    normal,
    uniform,
    uniformInt,
)
from gamspy.math.trigonometric import (
    acos,
    asin,
    atan,
    atan2,
    cos,
    cosh,
    sin,
    sinh,
    tan,
    tanh,
)

__all__ = [
    "cos",
    "cosh",
    "sin",
    "sinh",
    "acos",
    "asin",
    "tan",
    "tanh",
    "atan",
    "atan2",
    "exp",
    "power",
    "sqr",
    "sqrt",
    "log",
    "log2",
    "log10",
    "log_beta",
    "log_gamma",
    "logit",
    "abs",
    "ceil",
    "dist",
    "div",
    "div0",
    "factorial",
    "floor",
    "fractional",
    "Min",
    "Max",
    "mod",
    "Round",
    "sign",
    "binomial",
    "centropy",
    "normal",
    "uniform",
    "uniformInt",
    "cv_power",
    "rpower",
    "sign_power",
    "sllog10",
    "sqlog10",
    "vc_power",
    "slexp",
    "sqexp",
    "truncate",
    "ifthen",
    "beta",
    "regularized_beta",
    "gamma",
    "regularized_gamma",
    "entropy",
    "lse_max",
    "lse_max_sc",
    "lse_min",
    "lse_min_sc",
    "ncp_cm",
    "ncp_f",
    "ncpVUpow",
    "ncpVUsin",
    "poly",
    "rand_binomial",
    "rand_linear",
    "rand_triangle",
    "slrec",
    "sqrec",
    "errorf",
    "same_as",
    "sigmoid",
    "bool_and",
    "bool_eqv",
    "bool_imp",
    "bool_not",
    "bool_or",
    "bool_xor",
    "rel_eq",
    "rel_ge",
    "rel_gt",
    "rel_le",
    "rel_lt",
    "rel_ne",
]
